#!/usr/bin/env python

"""
A test of content preferences using examples from the HTTP 1.1 specification.
See: http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.1
"""

from MoinSupport import getContentPreferences

s0 = "audio/*; q=0.2, audio/basic"
prefs = getContentPreferences(s0)
oprefs = prefs.get_ordered(True)
expected = [
    ["audio/basic"],
    ["audio/*"]
    ]
print oprefs == expected, ":", oprefs, "==", expected

s1 = "text/plain; q=0.5, text/html, text/x-dvi; q=0.8, text/x-c"
prefs = getContentPreferences(s1)
oprefs = prefs.get_ordered(True)
expected = [
    ["text/html", "text/x-c"],          # equal quality, specificity
    ["text/x-dvi"],
    ["text/plain"]
    ]
print oprefs == expected, ":", oprefs, "==", expected

s2 = "text/*, text/html, text/html;level=1, */*"
prefs = getContentPreferences(s2)
oprefs = prefs.get_ordered(True)
expected = [
    ["text/html;level=1"],              # specificity is 1
    ["text/html"],                      # specificity is 0
    ["text/*"],                         # specificity is -1
    ["*/*"]                             # specificity is -2
    ]
print oprefs == expected, ":", oprefs, "==", expected

s3 = "text/*;q=0.3, text/html;q=0.7, text/html;level=1, text/html;level=2;q=0.4, */*;q=0.5"
prefs = getContentPreferences(s3)
oprefs = prefs.get_ordered(True)
expected = [
    ["text/html;level=1"],
    ["text/html"],                      # specificity is 1
    ["*/*"],                            # specificity is -2
    ["text/html;level=2"],
    ["text/*"]
    ]
print oprefs == expected, ":", oprefs, "==", expected

available = [
    "text/html;level=1",
    "text/html"
    ]
expected = ["text/html;level=1"]
print prefs.get_preferred_types(available) == expected, ":", prefs.get_preferred_types(available), "==", expected

available = [
    "text/plain",
    "image/jpeg"
    ]
expected = ["image/jpeg"]
print prefs.get_preferred_types(available) == expected, ":", prefs.get_preferred_types(available), "==", expected

available = [
    "text/html;level=2",
    "text/html;level=3"
    ]
expected = ["text/html;level=3"]
print prefs.get_preferred_types(available) == expected, ":", prefs.get_preferred_types(available), "==", expected

# vim: tabstop=4 expandtab shiftwidth=4
